import logging
import requests
import json


from commands.commandbase import CommandBase


log = logging.getLogger("").getChild(__name__)


class Validate(CommandBase):

    def __init__(
        self,
        new_schema: dict,
    ):
        self.new_schema = new_schema

        super(Validate, self).__init__()

    def run(self):
        print("its Validate")
        self.validate()

    def validate(self):
        # https://docs.confluent.io/platform/current/schema-registry/fundamentals/schema-evolution.html
        # https://docs.confluent.io/platform/current/schema-registry/index.html#schemaregistry-intro
        # Backward compatibility
        print("was validated")
        print({"new_schema": self.new_schema})
        return
        # TODO: replace with real host
        schema_registry_url: str = "http://localhost:8081"
        subject: str = "my-subject"
        # new_schema: dict = {
        #     "schema": json.dumps(
        #         {
        #             "type": "record",
        #             "name": "TestSchema",
        #             "fields": [{"name": "field1", "type": "string"}],
        #         }
        #     )
        # }

        response: requests.Response = requests.post(
            f"{schema_registry_url}/compatibility/subjects/{subject}/versions/latest",
            headers={"Content-Type": "application/vnd.schemaregistry.v1+json"},
            data=json.dumps(self.new_schema),
        )

        result = response.json()
        if result.get("is_compatible"):
            print("Schema is compatible")
        else:
            print("Schema is NOT compatible")



import logging
import re
import click
import json
# from src import commands
import commands

log = logging.getLogger(__name__)


@click.group()
@click.pass_context
def cli(
    ctx,
):
    ctx.ensure_object(dict)
    print("is cli")


@cli.command()
# @click.option("--new-schema", required=True, envvar="new_schema", type=dict)
@click.option("--new-schema", required=True, envvar="NEW_SCHEMA", help="JSON string with schema")
# @click.option("--new-schema", required=True, envvar="NEW_SCHEMA_PATH", type=click.Path(exists=True), help="Path to JSON schema file")
@click.pass_context
def validate(ctx, new_schema: str):
    # try:
    #     with open(new_schema, 'r') as f:
    #         schema_data = json.load(f)
    # except (json.JSONDecodeError, IOError) as e:
    #     raise click.BadParameter(f"Error loading schema: {e}")
    
    try:
        new_schema = json.loads(new_schema)
    except json.JSONDecodeError as e:
        raise click.BadParameter(f"Invalid JSON: {e}")
    
    cmd = commands.Validate(new_schema=new_schema)
    cmd.do_run()


@cli.command()
@click.pass_context
def publish_package(ctx):
    cmd = commands.PublishPackage()
    cmd.do_run()
